
harpiamm is an open-source Python library for the HARPIA-MM microscopy module
developed by [LIGHT CONVERSION](https://lightcon.com).

- **Feedback**: <a href="mailto:mls.software@lightcon.com" id="feedback">Report issue</a>

## Install
harpiamm is available via [PyPI](https://pypi.python.org/pypi/harpiamm/).
Install using `pip`:
```
  python -m pip install harpiamm
 ```
Copyright 2019-2024 Light Conversion
Contact: support@lightcon.com
